from pyramid.scaffolds import PyramidTemplate

class PyJinAlTemplate(PyramidTemplate):
    _template_dir = 'pyjinal_scaffold'
    summary = 'Pyramid project with Jinja2 and SQLAlchemy'
